# © 2022 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import models, api, fields


class ScopPartner(models.Model):
    _inherit = 'res.partner'

    date_bureau_validation = fields.Date(
        string="Date du bureau de validation",
        compute='_compute_date_bureau_validation')

    # ------------------------------------------------------
    # Compute
    # ------------------------------------------------------
    @api.multi
    def _compute_date_bureau_validation(self):
        """
        Date bureau adhesion is last instance type adhesion attached to partner
        :return:
        """
        for r in self:
            r.date_bureau_validation = None
            instance_adhesion_ids = r.instance_ids.filtered('is_type_membership')\
                .sorted('date_start')
            if instance_adhesion_ids:
                r.date_bureau_validation = instance_adhesion_ids[-1].\
                    date_start.date()

    # ------------------------------------------------------
    # Business method
    # ------------------------------------------------------
    @api.multi
    def get_theorical_amount_adhesion(self, effectif):
        """
        Trick to use super method to get amount adhesion in compute field
        in model scop_instance_partner
        """
        self.ensure_one()
        return super(ScopPartner, self).get_amount_adhesion(effectif)

    @api.multi
    def get_amount_adhesion(self, effectif):
        """
        Override function to get custom amount set in instance if exists
        """
        self.ensure_one()
        adhesion_from_instance = self.env[
            'scop.instance.partner'].search([
                ('instance_id', '=',
                 self.env.context.get('origin_instance_id')),
                ('partner_id', '=', self.id)
            ])
        if len(adhesion_from_instance) == 1 and \
                self.env.context.get('origin_instance_id'):
            amount_adhesion = adhesion_from_instance.amount_adhesion
        else:
            amount_adhesion = super(
                ScopPartner, self).get_amount_adhesion(effectif)
        return amount_adhesion
