# © 2022 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import fields, models, api
from odoo.exceptions import UserError


class ScopInstanceMailWizard(models.TransientModel):
    _name = 'scop.instance.mail.wizard'
    _description = "Wizard: Mail d'adhésion"

    @api.model
    def _get_partner_ids_domain(self):
        """
        Compute domain : coops from instance in active_id
        """
        res = [('id', 'in', 0)]  # Nothing accepted by domain, by default
        if self.env.context.get('active_model') == 'scop.instance':
            instance_id = self.env['scop.instance'].browse(
                self.env.context.get('active_id')
            )
            partner_ids = instance_id._get_partners().filtered(
                lambda i: i.project_status == '6_suivi')
            if partner_ids:
                res = [('id', 'in', partner_ids.ids)]
        return res

    partner_ids = fields.Many2many(
        comodel_name='res.partner',
        string='Coopératives',
        domain=lambda self: self._get_partner_ids_domain())

    @api.multi
    def send_mail(self):
        """
        Call function to send mail in mass from scop_instance
        """
        if self.env.context.get('active_model') == 'scop.instance':
            return self.env['scop.instance'].\
                browse(self.env.context.get('active_id')).\
                send_mass_mail_adhesion(self.partner_ids)
        else:
            raise UserError('Impossible d\'envoyer le mail')
